@@ -3,8 +3,8 @@ import os
 import requests
 
 @argh.arg("files", help="File(s) to load.")
-def main(verbose : "Display extra information about [[tags]] (not yet implemented)" =False,
-            all : "Concatenate all results into one .md file with shared [[tags]] (not yet implemented)"=False,
+def main(verbose : "Display extra information about [[tags]]" =False,
+            all : "Concatenate all results into one .md file with shared [[tags]]"=False,
             *files):
 
     if len(files) == 0:
